@@ -9,10 +9,9 @@ DATA_DIR = Path(__file__).parent.absolute() / "data"
 ETL_DATA_DIR = DATA_DIR / "etl"
 
 # ETL install version?
-ETL_VERSION = False
 try:
-    import selenium
+    from . import etl
 
     ETL_VERSION = True
-except:
-    pass
+except ImportError:
+    ETL_VERSION = False
